@@ -142,9 +142,6 @@ int main(int argc, char **argv)
     uint8_t empty_md5_hash[MD5_DIGEST_LENGTH] = { 0 };
     DEFER_CLEANUP(struct s2n_hash_state md5_hash = { 0 }, s2n_hash_free);
     EXPECT_SUCCESS(s2n_hash_new(&md5_hash));
-    if (s2n_is_in_fips_mode()) {
-        EXPECT_SUCCESS(s2n_hash_allow_md5_for_fips(&md5_hash));
-    }
     EXPECT_SUCCESS(s2n_hash_init(&md5_hash, S2N_HASH_MD5));
     EXPECT_SUCCESS(s2n_hash_digest(&md5_hash, empty_md5_hash, MD5_DIGEST_LENGTH));
 
@@ -159,21 +156,21 @@ int main(int argc, char **argv)
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_string(NULL, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), output_mem, &output_size),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_hash(NULL, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), output_mem, &output_size, &str_size),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
 
         /* Valid output buffer required */
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_string(client_hello, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), NULL, &output_size),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_hash(client_hello, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), NULL, &output_size, &str_size),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_string(client_hello, S2N_FINGERPRINT_JA3,
                         0, NULL, &output_size),
@@ -187,15 +184,15 @@ int main(int argc, char **argv)
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_string(client_hello, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), output_mem, NULL),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_hash(client_hello, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), output_mem, NULL, &str_size),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
         EXPECT_FAILURE_WITH_ERRNO(
                 s2n_client_hello_get_fingerprint_hash(client_hello, S2N_FINGERPRINT_JA3,
                         sizeof(output_mem), output_mem, &output_size, NULL),
-                S2N_ERR_NULL);
+                S2N_ERR_INVALID_ARGUMENT);
 
         /* Only JA3 currently supported */
         EXPECT_FAILURE_WITH_ERRNO(
@@ -256,8 +253,8 @@ int main(int argc, char **argv)
              * not when processing the actual ClientHello message.
              * So we need to set the versions manually.
              */
-            server->client_hello_version = S2N_SSLv2;
-            server->client_protocol_version = S2N_TLS12;
+            server->client_hello.sslv2 = true;
+            server->client_hello.legacy_version = S2N_TLS12;
 
             uint8_t sslv2_client_hello[] = {
                 SSLv2_CLIENT_HELLO_PREFIX,
